import os

from flask import Flask
from flask_compress import Compress
from flask_cors import CORS
from flask_sqlalchemy import SQLAlchemy
from werkzeug.middleware.proxy_fix import ProxyFix

# If available, load environment variables from .env before rest of the package
if os.path.isfile(".env"):
    from dotenv import load_dotenv

    load_dotenv()

from controller import api

########################################################################################################################
# Setup / Configuration
########################################################################################################################

# Instantiate app
app = Flask(__name__)
app.config["SQLALCHEMY_DATABASE_URI"] = os.environ["YOUR_CONN_STRING_ENV"]
app.config["SQLALCHEMY_TRACK_MODIFICATIONS"] = False
app.wsgi_app = ProxyFix(app.wsgi_app)  # Fixes Swagger UI issues over HTTPS

# Add extensions
db = SQLAlchemy(app)
CORS(app)
api.init_app(app)
Compress(app)


########################################################################################################################
# Run / Debug
########################################################################################################################

if __name__ == "__main__":
    if os.getenv("FLASK_ENV") == "development":
        app.run()



import os
import subprocess
import shutil
import sys

from halo import Halo


__author__ = "Andrew Mickael"
__version__ = "0.0.5"

TEMPLATE_DIR = "template"
PLACEHOLDER = "{{ %SERVICE_NAME% }}"


class CreateService:
    def __init__(self, service_name: str, root_dir: str):
        self.service_name = "-".join(service_name.split(" "))
        self.root_dir = root_dir
        self.template_dir = os.path.join(
            os.path.dirname(os.path.abspath(__file__)), TEMPLATE_DIR
        )

        # Check if service directory already exists, if it does then prompt for overwrite
        self.cwd = os.path.join(self.root_dir, self.service_name)
        if os.path.exists(self.cwd):
            proceed = input("Directory already exists, overwrite? [y/N]: ")
            if proceed.lower() == "y":
                shutil.rmtree(self.cwd)
            else:
                print("Stopping")
                exit()

    def create_tree(self):
        # Copy file structure
        shutil.copytree(
            self.template_dir, self.cwd, ignore=shutil.ignore_patterns("__pycache__")
        )

        return self

    def generate_venv(self):
        # Generate venv
        subprocess.run([sys.executable, "-m", "venv", f"{self.cwd}{os.sep}venv"])

        return self

    def install_requirements(self):
        # Install requirements
        subprocess.Popen(
            " && ".join(
                [
                    f"source {self.cwd}/venv/bin/activate"
                    if os.name == "posix"
                    else fr"{self.cwd}\Scripts\activate.bat",
                    f"pip install -r {self.cwd}{os.path.sep}requirements.txt",
                    "deactivate",
                ]
            ),
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL,
            shell=True,
        ).communicate()

        return self

    def initialize_git(self):
        subprocess.Popen(
            f"cd {self.cwd} && git init && git add .",
            stdout=subprocess.DEVNULL,
            stderr=subprocess.DEVNULL,
            shell=True,
        ).communicate()

        return self

    def __placeholder(self, file_name: str):
        file_path = os.path.join(self.cwd, file_name)
        with open(file_path, "r", encoding="utf-8") as f:
            text = f.read().replace(PLACEHOLDER, self.service_name)
        with open(file_path, "w", encoding="utf-8") as f:
            f.write(text)

    def personalize(self):
        self.__placeholder("README.md")
        self.__placeholder(os.path.join("controller", "__init__.py"))


def main():
    try:
        # Prompt input
        service_name = input("Service name: ")
        root_dir = input("Root directory (blank for current directory): ")
        service = CreateService(service_name, root_dir)

        # Create file structure
        spinner = Halo(text="Creating file structure")
        spinner.start()
        service.create_tree()
        spinner.succeed()

        # Generate venv
        spinner.start("Generating virtual environment")
        service.generate_venv()
        spinner.succeed()

        # Activate venv and install requirements
        spinner.start("Installing requirements")
        service.install_requirements()
        spinner.succeed()

        # Initialize git
        spinner.start("Initializing git repository")
        service.initialize_git()
        spinner.succeed()

        # Personalize
        spinner.start("Personalizing")
        service.personalize()
        spinner.succeed()

        # Done!
        spinner.stop_and_persist("🎂".encode("utf-8"), "All done!")
        print("Your new project is located in:", os.path.abspath(service.cwd), sep="\t")
    except (KeyboardInterrupt, SystemExit):
        pass


if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

import create_flask_service

with open("README.md", "r") as f:
    readme = f.read()

setup(
    name="create-flask-service",
    version=create_flask_service.__version__,
    description="Create a Flask microservice with a few keystrokes",
    long_description=readme,
    long_description_content_type="text/markdown",
    author=create_flask_service.__author__,
    author_email="andrew.mickael@gmail.com",
    license="MIT",
    platforms=["NT", "POSIX"],
    url="https://github.com/amickael/create-flask-service",
    packages=find_packages(exclude=("create_flask_service.template",)),
    include_package_data=True,
    zip_safe=False,
    entry_points={
        "console_scripts": ["create-flask-service = create_flask_service:main"]
    },
    install_requires=["halo"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Environment :: Console",
    ],
    python_requires=">=3.6",
)
